---
name: Custom issue
about: When no other template fits.
title: ''
labels: ''
assignees: ''

---

**Please search issues in https://github.com/skodaconnect/skodaconnect and https://github.com/skodaconnect/homeassistant-skodaconnect for duplicates or fixes before reporting a new issue.**


